py_get_exchange_rate

Function py_get_exchange_rate 

pub fn py_get_exchange_rate(
    from_currency: &str,
    to_currency: &str,
    price_type: PriceType,
    quotes_bid: HashMap<String, f64>,
    quotes_ask: HashMap<String, f64>,
) -> PyResult<Option<f64>>
Calculates the exchange rate between two currencies using provided bid and ask quotes.

This function builds a graph of direct conversion rates from the quotes and uses a DFS to accumulate the conversion rate along a valid conversion path. While a full Floyd–Warshall algorithm could compute all-pairs conversion rates, the DFS approach here provides a quick solution for a single conversion query.